// ===========================================================================
//
// Test Drive 7 : AssembleOrderCreate.java
//
// ===========================================================================
// MQSeries Java application (Alan Hollingshead)
//
// This class assembles an input message for MQSeries Integrator (e.g. ORDERS02) to create an IDOC.
// Data fields are read from a flat text file.
//
// Input:  Passed in <filename> 
// Output: Successful or failure message
//  
// open input file
// read line until end-of-file
//    if * then treat as comment and ignore
//    if <    > then treat as tag and add asis to InputDataString
//      repeat until line starts with <\ (end of tag) 
//      for each line data to be added to string is whole length of line, minus (location of first space + 1)
//      add hash to denote end of field to MQSeries Integrator
//      end-repeat loop
// repeat read line loop
// close input file
//

import java.io.*;
import java.util.*;

public class AssembleOrderCreate 
{
   public static void main(String[] args)
   {
      String            sInputFile      = null;
      String            sQMgr           = null;
      String            sQName          = "MQSI_IN";                            // Input qname for MQSI on F/E system
      String            sOutputString   = "";
      String            sDelimiter      = "#";

      String            sLine           = null;
      FileInputStream   file            = null;
      InputStreamReader isReader        = null;
      BufferedReader    brReader        = null;

      try 
      {      
         sQMgr      = args[0];
         sInputFile = args[1];   
   
         // ----------------------------------------------------------------------------------------
         // Open input file
         // ----------------------------------------------------------------------------------------      
      

            file     = new FileInputStream(sInputFile);
            isReader = new InputStreamReader(file);
            brReader = new BufferedReader(isReader);
         
            sLine = brReader.readLine();
            
            // System.out.println("First line: "+sLine);
                  
            while (sLine != null) 
            {
               // read line until end-of-file
               //    if * then treat as comment and ignore
               //    if <    > then treat as tag and add asis to InputDataString
               //      repeat until line starts with <\ (end of tag) 
               //      for each line data to be added to string is whole length of line, minus (location of first space + 1)
               //      add hash to denote end of field to MQSeries Integrator
               //      end-repeat loop
               // repeat read line loop               
                
               char sFirstChar = sLine.charAt(0);
               // System.out.println("First char of "+sLine+ " is: "+sFirstChar);
               
               switch(sFirstChar) 
               {
                  case '*'      : // ignore comment lines
                                  break;
                                  
                  case '<'      : // add tags asis without appending hash
                                  int iDataTagEnd = sLine.indexOf('>');
                                  String sDataTag = sLine.substring(0,iDataTagEnd+1);
                                  sOutputString = sOutputString + sDataTag;      
                                  break;
                               
                  default       : // append data following first space unless hash is found to imply no data
                                  int iDataStarts = sLine.indexOf(' ');
                                  if (sLine.indexOf("#") > 1)
                                     sOutputString = sOutputString + "#";
                                  else
                                     sOutputString = sOutputString + sLine.substring(iDataStarts+1, sLine.length()) + "#";                                     
               }                   
                  
            // read next line   
            sLine = brReader.readLine();   
            }
         }
         catch (ArrayIndexOutOfBoundsException abe)
         {
            System.out.println("Usage: AssembleOrderCreate <local Qmgr> <input filename>");
            System.exit(0);
         }
         catch (FileNotFoundException fnfe)
         {
            System.err.println("Error: "+ fnfe);
            System.exit(0);
         }
         catch (IOException ioe)
         {
            System.err.println("IOException: "+ ioe);               
            System.exit(0);
         }
         catch (Exception e)
         {
            System.err.println("Exception caught (possibly due to end of file): "+ e);               
            // System.exit(0);
         }
         
         finally
         {
            try
            {
               file.close();
            }
            catch (IOException ioe)
            {
               System.err.println("Error closing file: "+ ioe);
               System.exit(0);
            }
         } 
        System.out.println(sOutputString);

      // put string onto input queue for MQSI
      MessageIO.PutMessage(sQMgr, sQName, sOutputString);
   }
}
