// ===========================================================================
//
// Test Drive 7 : PutGetMsg.java
//
// ===========================================================================
// MQSeries Java application (Alan Hollingshead - August 99)
//
// This class serves two purposes:
// 1. Reads one or more lines from an input file and issues an MQPUT
// 2. Issues a single MQGET and writes the message to a file 
//
// "Usage: PutGetMsg <PUT | GET> <filename> <queue> <local QMgr>"
// 
// Currently, the MQGET will overwrite any existing data in the file specified 
// 

import java.io.*;
import java.util.*;

public class PutGetMsg 
{
   public static void main(String[] args)
   {
      // Command line parameters
      String            sPutGetOption   = null;
      String            sInOutFile      = null;
      String            sQName          = null;   
      String            sQMgr           = null;      

      // File variables
      String              sLine         = null;
      FileInputStream     fiFile        = null;
      FileOutputStream    foFile        = null;
      InputStreamReader   isReader      = null;
      BufferedReader      brReader      = null;
      OutputStreamWriter  osWriter      = null;
      BufferedWriter      bwWriter      = null;   

      try 
      {      
         sPutGetOption = args[0];
         sInOutFile    = args[1];
         sQName        = args[2];
         sQMgr         = args[3];
         
         // upper case sPutGetOption input parameter  
         sPutGetOption.toUpperCase();         
 
         if (sPutGetOption.equals("PUT"))
         {         
            // ----------------------------------------------------------------------------------------
            // PUT Option            
            // ----------------------------------------------------------------------------------------       
          
            // prepare file for read from
            fiFile   = new FileInputStream(sInOutFile);
            isReader = new InputStreamReader(fiFile);
            brReader = new BufferedReader(isReader);                   
          
            System.out.println("Reading file: "+sInOutFile);   
     
            // read from file
         
            sLine = brReader.readLine();
                  
            while (sLine != null) 
            {
               System.out.println("Line read: "+sLine);
               MessageIO.PutMessage(sQMgr, sQName, sLine);                                          
               // read next line   
               sLine = brReader.readLine();   
            }
            
            // close file
            fiFile.close();
                        
            System.out.println("MQPUT from "+sInOutFile+" to queue "+sQName+" complete");
            System.exit(0);
         }
         else
         {         
            // ----------------------------------------------------------------------------------------
            // GET Option            
            // ----------------------------------------------------------------------------------------                
            
            // prepare file to write to
            foFile   = new FileOutputStream(sInOutFile);
            osWriter = new OutputStreamWriter(foFile);
            bwWriter = new BufferedWriter(osWriter);         
            
            sLine = MessageIO.GetMessage(sQMgr, sQName);
            
            // write to file            
            bwWriter.write(sLine);
            bwWriter.flush();            

            // close file
            foFile.close();
            
            System.out.println("MQGET from queue "+sQName+" to file "+sInOutFile+" complete");
            System.exit(0);            
         }   
      }   
      
      // ----------------------------------------------------------------------------------------
      // catch exceptions
      // ----------------------------------------------------------------------------------------   
      catch (ArrayIndexOutOfBoundsException abe)
      {
         System.out.println("Usage: PutGetMsg <PUT | GET> <filename> <queue> <local QMgr>");
         System.out.println("  e.g. PutGetMsg PUT File.In MyQueue MyQMgr");
         System.out.println(" Note: All parameters are mandatory");            
         System.exit(0);
      }
      catch (FileNotFoundException fnfe)
      {
         System.err.println("Error: "+ fnfe);
         System.exit(0);
      }
      catch (IOException ioe)
      {
         System.err.println("IOException: "+ ioe);               
         System.exit(0);
      }
      catch (Exception e)
      {
         System.err.println("Exception caught: "+ e);               
         System.exit(0);
      }         
   }
}
