// ===========================================================================
//
// Test Drive 7 : StartRqstrChannel.java
//
// ===========================================================================
// MQSeries Java application (Alan Hollingshead)
//
// Input: StartRqstrChannel <shortname> <RegSys QMgr name>
//
// The <shortname> is assumed to be the local queue manager name, and used as part of the channel name
//
// Command server must be active to accept PCF requests 
// "strmqcsv <QMgrName>" starts the command server
//
//

import com.ibm.mqbind.*;                                             // include the MQ bindings package
import com.ibm.mqbind.pcf.*;                                         // include MQ PCF package ... requires SupportPac
import java.io.*;
import java.util.*;

public class StartRqstrChannel
{
   static MQMessage []   responses;
   static MQCFH          cfh;
   static PCFParameter   p;
   
   public static void main(String[] args)
   {
      String sShortname  = args[0];
      String sRegSysQMgr = args[1];      

      try
      {   
         PCFAgent agent;
      
         // Connect a PCFAgent to the specified queue manager
         System.out.println("\nConnecting to queue manager " + sShortname + "... ");
         agent = new PCFAgent (sShortname);
         
         System.out.println ("Sending PCF requests ... ");


         // --------------------------------------------------------------------------------------------------------------
         // Start Requester Channel
         // --------------------------------------------------------------------------------------------------------------

         String sRequesterChannelName = sRegSysQMgr + "." + sShortname;
         PCFParameter[] startRequesterChannelParameters = 
                        {
                           new MQCFST (CMQCFC.MQCACH_CHANNEL_NAME, sRequesterChannelName)
                        };        

         System.out.print ("   Start requester channel          '"+sRequesterChannelName+"'... ");

         // Use the agent to send the request
         responses = agent.send (CMQCFC.MQCMD_START_CHANNEL, startRequesterChannelParameters);

         // check responses
         checkResponses();                                                      
                             
      }
      catch (MQException mqe)
      {
         switch (mqe.reasonCode)
         {                                                                   
            case 2059 : System.out.println ("RC 2059. Local Queue Manager not started");
                                                                
            default   : System.out.println ("MQ exception caught:\n" + mqe);
         }   
         System.exit(0);                       
      }
      catch (IOException ioe)
      {
         System.err.println (ioe);
         System.exit(0);   
      }
      System.exit(0);
   } 

   // ----------------------------------------------------------------------------------------------------------------
   // Method: checkResponses()
   // ----------------------------------------------------------------------------------------------------------------
   public static void checkResponses()
   {
      try
      {
         for (int i = 0; i < responses.length; i++)
         {
            cfh = new MQCFH (responses [i]);
         
            // Check the PCF header (MQCFH) in the response message

            switch (cfh.reason)
            {
               case 0    : System.out.println ("OK");      
                           break;                                                             
                                      
               case 3065 : System.out.println ("Channel status unknown");
                           i++;    // to ignore PCF failed message
                           break;                                                
                           
               case 4031 : System.out.println ("Channel in use");
                           i++;    // to ignore PCF failed message
                           break;                               
                                                                       
               case 4042 : System.out.println ("Channel already exists");
                           i++;    // to ignore PCF failed message
                           break;                               
                        
               default   : System.out.println ("PCF error:\n" + cfh);

               // Walk through the returned parameters describing the error

               for (int j = 0; j < cfh.parameterCount; j++)
               {
                  System.out.println (PCFParameter.nextParameter (responses [0]));
               }
            }
         }
      }

      // ----------------------------------------------------------------------------------------
      // catch exceptions
      // ----------------------------------------------------------------------------------------         
      catch (ArrayIndexOutOfBoundsException abe)
      {
         System.out.println("Usage: Usage: java StartChannels <shortname> <RegSys QMgr>");
         System.out.println("  e.g. StartChannels HOLLINGS REGSYS");
         System.out.println(" Note: All parameters are mandatory");            
         System.exit(0);
      }             
      catch (EOFException eofe)
      {
         ;
      }
      catch (IOException ioe)
      {
         System.err.println (ioe);
      }       
      catch (InstantiationException ie)
      {
         System.err.println (ie);
      }          
   }
}



