// ===========================================================================
//
// Test Drive 7 : SupplyShortname.java
//
// ===========================================================================
// MQSeries Java application (Alan Hollingshead)
//
// Takes shortname as input parameter. This is the name used during registration of the reserved logical SAP system.
// This shortname is the name of the Java/MQSI Front-End queue manager.
//
// Application issues an MQPUT onto remote queue REGISTERQ.REMOTE
// This will trigger CheckRegistration application on Registration System
// 
// Input example: java SupplyShortname HOLLINGS
//

import com.ibm.mqbind.*;                                             // include the MQ bindings package
import com.ibm.mqbind.pcf.*;                                         // include MQ PCF package ... requires SupportPac
import java.io.*;
import java.util.*;

public class SupplyShortname 
{
   public static void main(String[] args)
   {
      try
      {
         String sLocalQMgr  = null;
         String sRegisterQ  = "REGISTERQ.REMOTE";                    // name of registration queue
         String sRegSysQMgr = null;
         String sRegSysAddress = "9.20.20.198";
      
         sLocalQMgr  = args[0];                                      // Java/MQSI Front-End QMgr
         sRegSysQMgr = args[1];
         sRegSysAddress = args[2];         
      
         System.out.println("\nLocal queue manager will be: "+ sLocalQMgr);

         // Call FrontEndPCF to create MQ definitions using PCF
         FrontEndPCF.DefineFrontEndDefs(sLocalQMgr, sRegSysQMgr, sRegSysAddress);

         // Call to issue MQPUT
         // Passing parameters: Local QMgr, queue name, and message data (uses name of Local QMgr - i.e. shortname)
         System.out.println("Put message onto "+sRegisterQ);
         MessageIO.PutMessage(sLocalQMgr, sRegisterQ, sLocalQMgr);
      
         // All Front-End processing finished
         System.out.println("All front-end processing complete");
   
         System.exit(0);
      }   

      // ----------------------------------------------------------------------------------------
      // catch exceptions
      // ----------------------------------------------------------------------------------------         
      catch (ArrayIndexOutOfBoundsException abe)
      {
         System.out.println("Usage: SupplyShortname <shortname> <RegSys QMgr>");
         System.out.println("  e.g. SupplyShortname HOLLINGS REGSYS");
         System.out.println(" Note: All parameters are mandatory");            
         System.exit(0);
      }
   }
}
