@ECHO OFF
REM ***************************
REM Test Drive 7 parameters set
set USERNAME=USERID
set PASSWORD=PASSWORD
set DB=MQSIDB
REM ***************************

REM these variables should be set by the NEON software build process

set INSTALL_TYPE=MQSI
set DB_SHORT_NAME=db2
set VERSION=110

REM initialize batch variables from command line arguments
REM NOTE:  For null passwords, enter 2 single quotes on command line as a
REM place holder for the password argument.

rem set USERNAME=%1
rem set PASSWORD=%2

REM check for existence of required command line arguments

if "%USERNAME%" == "help" goto command_line_syntax
if "%USERNAME%" == ""     goto command_line_syntax
if "%PASSWORD%" == ""     goto command_line_syntax

REM check product specific components from command line

if "%DB_SHORT_NAME%" == "syb" goto check_sybase_command_line
if "%DB_SHORT_NAME%" == "mssql" goto check_sybase_command_line
if "%DB_SHORT_NAME%" == "db2" goto check_db2_command_line
if "%DB_SHORT_NAME%" == "ora" goto check_oracle_command_line

:check_sybase_command_line

REM replace placeholder password with empty value for null passwords

if "%PASSWORD" == "''" set PASSWORD=

if "%DB_SHORT_NAME%" == "syb" set DBMS=sybase
if "%DB_SHORT_NAME%" == "mssql" set DBMS=mssql
set SERVER=%3
set DB=%4

if "%SERVER%" == "" goto command_line_syntax
if "%DB%" == ""     goto command_line_syntax

set ARGLIST=%USERNAME% %PASSWORD% %SERVER% %DB%
set SQLSVSES=%SERVER%:%USERNAME%:%PASSWORD%:%DB%

goto after_dbms_check

:check_db2_command_line

set DBMS=db2
rem set DB=%3

if "%DB%" == ""     goto command_line_syntax

set ARGLIST=%USERNAME% %PASSWORD% %DB%
set SQLSVSES=%DB%:%USERNAME%:%PASSWORD%:

goto after_dbms_check

:check_oracle_command_line

set DBMS=oracle
set SERVER=%3

if "%SERVER%" == "" goto command_line_syntax

set ARGLIST=%USERNAME% %PASSWORD% %SERVER%
set SQLSVSES=%SERVER%:%INSTALL_TYPE%%VERSION%:%INSTALL_TYPE%%VERSION%:

goto after_dbms_check

:after_dbms_check

REM print banner message

cls
echo.
type banner
echo.
echo.
echo This procedure installs database schema in the database specified
echo by the command-line parameters.  This procedure will take between
echo 10 and 45 minutes, depending on the server's processor speed and
echo current activity.  It is strongly recommended you perform a complete
echo backup of all files and databases before installing any software
echo product.  The command line entered database must already exist on the
echo specified database server and must contain the appropriate table spaces
echo (Oracle and DB2)/user defined segments (Sybase and Microsoft SQL Server)
echo as described in the documentation.  

pause

REM print status message

echo Preparing to install a product (%INSTALL_TYPE%) version (%VERSION%) type (%DBMS%) database.
echo.
echo Output from this script can be found in the file (%temp%\inst_db.log).

REM call script to install database components depending on INSTALL_TYPE
 
if "%INSTALL_TYPE%" == "NEONet" goto NEONet_install
if "%INSTALL_TYPE%" == "MQI" goto MQI_install
if "%INSTALL_TYPE%" == "MQSI" goto MQI_install

echo We have not implemented this kind of installation yet.

:NEONet_install

call sqlload %temp%\inst_db.log %DBMS% %ARGLIST% F Q R

goto after_install

:MQI_install

call sqlload %temp%\inst_db.log %DBMS% %ARGLIST% F R

:after_install

REM prompt user for whether or not to load NEON standard formatter components

if "%ERROR_STATUS%" == "0" goto prompt_std_comps
if NOT "%ERROR_STATUS%" == "0" goto end

:prompt_std_comps

REM *** Load of standard NEON components disabled for IBM ASG Test Drives
echo.
echo Load of standard NEON components bypassed as these are not required for 
echo IBM ASG Test Drives
goto end

echo.
echo The NEON standard formatter components library consists of a set of
echo commonly used literal values and substitute output operations.
echo.
echo Would you like to install these NEON components?

../bin/NNYORN

REM import standard components

if "%ERRORLEVEL%" == "0" goto load_std_comps
if NOT "%ERRORLEVEL%" == "0" goto end

:load_std_comps

REM generate sqlsvses.cfg file

echo nnfie:%SQLSVSES% > sqlsvses.cfg

REM set up shared object path

set PATH=..\lib;%PATH%

echo.
echo Importing data for standard formatter components library.

REM remove prior occurrences of NNFie log file
 
if exist NNFie.log del NNFie.log

REM load each export file in examples directory

for %%e in (..\examples\literals.exp ..\examples\operations.exp) do ..\bin\NNFie -i %%e -4

REM present information used to determine status of components load
 
echo Please check the contents of the NNFie.log file to determine the
echo success/failure of the standard components installation.  Also,
echo check for the existence of an NNFie.err file in this directory. 
echo If a failure occurred, these components can be loaded using the 
echo NNFie program located in the bin directory of your installation.
echo The component files (literals.exp, operations.exp) are located
echo in the examples directory of your installation.
 
REM remove config. file used by NNFie

del sqlsvses.cfg

goto end

:command_line_syntax

echo.
echo Command line parameters for inst_db:
echo.
echo - Sybase and Microsoft:
echo.
echo   inst_db.cmd user_name user_password db_server db_name
echo.
echo      user_name           - login name for database
echo      user_password       - password for login name
echo      db_server           - database server name
echo      db_name             - database name
echo.
echo - IBM (DB2) and Oracle:
echo.
echo   inst_db.cmd user_name user_password db_instance/alias
echo.
echo      user_name           - login name for database
echo      user_password       - password for login name
echo      db_instance         - server instance name (Oracle)
echo      alias               - database alias name (DB2)
echo.

:end

echo.
pause
exit
