// ===========================================================================
//
// Test Drive 7 : CheckRegistration.java
//
// ===========================================================================
// MQSeries Java application (Alan Hollingshead)
//
// Application issues an MQGET from the REGISTERQ.
// Data in the MQGET message should contain shortname.
// The shortname is compared to the entries in the SAPBookings.dat file.
// 
// Input parameters: queue manager name of registration system
//                   register queue name on registration system
//                   filename containing bookings                   
//

import java.io.*;
import java.util.*;

public class CheckRegistration 
{
   public static void main(String[] args)
   {
     
//      String sQMgr = "REGSYS";                            // Registration System queue manager object
//      String sRegisterQ = "REGISTERQ";                    // name of registration queue
//      String sFilename  = "SAPBookings.dat";              // name of SAP reservation entries file

      try
      {
         String sQMgr           = args[0];
         String sRegisterQ      = args[1];
         String sFilename       = args[2];
        
         // call to issue MQGET
         String sNameReceived = MessageIO.GetMessage(sQMgr, sRegisterQ);
         System.out.println("Response from MessageIO: "+sNameReceived);

         if (sNameReceived == null) 
         {
            System.out.println("MQGET from "+sRegisterQ+" failed (null data). Quitting!");
            System.exit(0);
         }

         // call to LookUpName.class
         String sLookUpResponse = LookUpName.SuppliedName(sNameReceived, sFilename);
         System.out.println("Response from LookUpName: "+sLookUpResponse);
   
         // If cross-check proved successful, call RegSysPCF passing shortname and SAP system name (SYS1, etc)
         // System.out.println(sLookUpResponse.substring(0,3));
      
         if (sLookUpResponse.startsWith("SYS")) 
         { 
            int space1 = sLookUpResponse.indexOf(" ",1);           
            String sSAPsystem = sLookUpResponse.substring(0,space1);
            
            int iSalesOffice = sLookUpResponse.indexOf("80",space1);
            String sSalesOffice = sLookUpResponse.substring(iSalesOffice, iSalesOffice+4);
            System.out.println("\nUsing SAP system: "+ sSAPsystem +" with Sales Office: "+sSalesOffice); 
             
            // Set up MQ definitions 
            RegSysPCF.SetUpDefinitions(sNameReceived, sSAPsystem);
         }
         else 
         {
            System.out.println("Cross-check unsuccessful");
         }
      
         System.exit(0);
      } 
      
      // ----------------------------------------------------------------------------------------
      // catch exceptions
      // ----------------------------------------------------------------------------------------   
      catch (ArrayIndexOutOfBoundsException abe)
      {
         System.out.println("Error: Requires three input parameters - qmgr, registerq, filename");
         System.out.println("       Refer to CheckRegistration.java for more info.");
         System.out.println("Note:  All parameters are mandatory");            
         System.exit(0);
      }
   }      
}

