// ===========================================================================
//
// Test Drive 7 : MessageIO.java
//
// ===========================================================================
// MQSeries Java application (Alan Hollingshead)
//
// Application issues an MQGET or MQPUT from the queue passed in, e.g. REGISTERQ.
// The message is returned to the calling program.
// 
// 
//

import com.ibm.mqbind.*;                                         // Include the MQ bindings package
import java.io.*;
import java.util.*;

public class MessageIO 
{
   //
   // Method to MQGET messages
   //
   public static String GetMessage(String sQMgr,
                                   String sQName)
   {
      MQQueueManager qMgr;                                      // define a queue manager object
      String sMessageReceived = null;
  
      try 
      {
         // Create a connection to the queue manager
         qMgr = new MQQueueManager(sQMgr);

         // Set up the options on the queue we wish to open...
         // Note. All MQ Options are prefixed with MQC in Java.

         // +++++++++++++++++++++++++++++++++++++++++ need to check next line with doc - should be OUTPUT only for REGISTERQ?
         int openOptions = MQC.MQOO_INPUT_AS_Q_DEF |
                           MQC.MQOO_OUTPUT ;

         // Specify the queue to open, and the open options...
         MQQueue system_default_local_queue =
              qMgr.accessQueue(sQName,
                               openOptions,
                               null,           // default q manager
                               null,           // no dynamic q name
                               null);          // no alternate user id


         // Get the message 
         // First define a MQ message buffer to receive the message into..
         MQMessage retrievedMessage = new MQMessage();

         // Set the get message options..
         MQGetMessageOptions gmo = new MQGetMessageOptions();  // accept the defaults
                                                               // same as MQGMO_DEFAULT
         // get the message off the queue..
         system_default_local_queue.get(retrievedMessage,
                                     gmo,
                                     32000);                   // max message size

         // display message content
         sMessageReceived = retrievedMessage.readLine();
         System.out.println("MQGET message:" + sMessageReceived);

         // Close the queue
         system_default_local_queue.close();
      
         // Disconnect from the queue manager
         // System.out.println("Disconnect from queue manager");
         qMgr.disconnect();
      }

      // If an error has occurred, identify what went wrong.
      // Was it an MQ error?

      catch (MQException ex)
      {
         System.out.println("An MQ error occurred : Completion code " +
                         ex.completionCode +
                         " Reason code " + ex.reasonCode);
      }
      // Was it a Java buffer space error?
      catch (java.io.IOException ex)
      {
         System.out.println("An error occurred whilst writing to the message buffer: " +
                         ex);
      }
   return sMessageReceived;
   } 
   
   //
   // Method to MQPUT messages
   //
   
   public static void PutMessage(String sQMgr,
                                 String sQName,
                                 String sPutMessage)
   {
      MQQueueManager qMgr;                                      // define a queue manager object
  
      try 
      {
         // Create a connection to the queue manager
         qMgr = new MQQueueManager(sQMgr);

         // Set up the options on the queue we wish to open...
         // Note. All MQ Options are prefixed with MQC in Java.

         // +++++++++++++++++++++++++++++++++++++++++ need to check next line with doc - should be OUTPUT only for REGISTERQ?
         int openOptions = MQC.MQOO_INPUT_AS_Q_DEF |
                           MQC.MQOO_OUTPUT ;

         // Specify the queue to open, and the open options...
         MQQueue system_default_local_queue =
              qMgr.accessQueue(sQName,
                               openOptions,
                               null,           // default q manager
                               null,           // no dynamic q name
                               null);          // no alternate user id


         // MQPUT the message 

         MQMessage mqPutMessage = new MQMessage();
         // mqPutMessage.writeUTF(sPutMessage);
         mqPutMessage.writeBytes(sPutMessage);
         
         // Set the put message options..
         MQPutMessageOptions pmo = new MQPutMessageOptions();  // accept the defaults
                                                               // same as MQGMO_DEFAULT
         // put the message off the queue..
         system_default_local_queue.put(mqPutMessage,
                                        pmo);

         // Close the queue
         system_default_local_queue.close();
      
         // Disconnect from the queue manager
         // System.out.println("Disconnect from queue manager");
         qMgr.disconnect();
      }

      // If an error has occurred, identify what went wrong.
      // Was it an MQ error?

      catch (MQException ex)
      {
         System.out.println("An MQ error occurred : Completion code " +
                         ex.completionCode +
                         " Reason code " + ex.reasonCode);
      }
      // Was it a Java buffer space error?
      catch (java.io.IOException ex)
      {
         System.out.println("An error occurred whilst writing to the message buffer: " +
                         ex);
      }
   return;
   } 
}
