// ===========================================================================
//
// Test Drive 7 : ResetChannel.java
//
// ===========================================================================
// MQSeries Java application (Alan Hollingshead)
//
// Application issues an MQGET from the RESETQ.
// Data in the MQGET message should contain shortname/queue manager name.
// The queue manager name is used as part of the channel name to reset e.g. REGSYS.HOLLINGS
// 
// Input parameters: queue manager name of registration system
//                   reset queue name containing the message
//

import java.io.*;
import java.util.*;

public class ResetChannel 
{
   public static void main(String[] args)
   {
     
//      String sQMgr = "REGSYS";                            // Registration System queue manager object
//      String sResetQ = "RESETQ";                          // name of reset queue

      try
      {
         String sQMgr           = args[0];
         String sResetQ         = args[1];
        
         // call to issue MQGET
         String sNameReceived = MessageIO.GetMessage(sQMgr, sResetQ);
         System.out.println("Response from MessageIO: "+sNameReceived);

         if (sNameReceived == null) 
         {
            System.out.println("MQGET from "+sResetQ+" failed (null data). Quitting!");
            System.exit(0);
         }

         // call to RegSysPCF.class to reset channel
         String sChannelToReset = sQMgr + "." + sNameReceived;
         System.out.println("Channel to reset: "+sChannelToReset);
              
         RegSysPCF.ResetChannel(sChannelToReset);
               
         System.exit(0);
      } 
      
      // ----------------------------------------------------------------------------------------
      // catch exceptions
      // ----------------------------------------------------------------------------------------   
      catch (ArrayIndexOutOfBoundsException abe)
      {
         System.out.println("Error: Requires two input parameters - qmgr, resetq");
         System.out.println("       Refer to ResetChannel.java for more info.");
         System.out.println("Note:  All parameters are mandatory");            
         System.exit(0);
      }
   }      
}

